@@ -36,7 +36,6 @@ def test_fs_storage_no_explicit_base_dir(
         ),
         environment_yaml=[
             os.path.join(environments_path, "env.yaml"),
-            os.path.join(environments_path, "env_filesystem_no_explicit_base_dir.yaml"),
         ],
         image=dagster_docker_image,
     )
@@ -69,7 +68,7 @@ def test_fs_storage(
 def test_s3_storage(
     dagster_airflow_docker_operator_pipeline, dagster_docker_image
 ):  # pylint: disable=redefined-outer-name
-    pipeline_name = "demo_pipeline"
+    pipeline_name = "demo_pipeline_s3"
     environments_path = get_test_project_environments_path()
     results = dagster_airflow_docker_operator_pipeline(
         pipeline_name=pipeline_name,
@@ -130,7 +129,7 @@ def test_skip_operator(
 
 @requires_airflow_db
 def test_error_dag_containerized(dagster_docker_image):  # pylint: disable=redefined-outer-name
-    pipeline_name = "demo_error_pipeline"
+    pipeline_name = "demo_error_pipeline_s3"
     recon_repo = ReconstructableRepository.for_module(
         "dagster_test.test_project.test_pipelines.repo", "define_demo_execution_repo"
     )
@@ -164,7 +163,7 @@ def test_error_dag_containerized(dagster_docker_image):  # pylint: disable=redef
 def test_airflow_execution_date_tags_containerized(
     dagster_docker_image,
 ):  # pylint: disable=redefined-outer-name, unused-argument
-    pipeline_name = "demo_airflow_execution_date_pipeline"
+    pipeline_name = "demo_airflow_execution_date_pipeline_s3"
     recon_repo = ReconstructableRepository.for_module(
         "dagster_test.test_project.test_pipelines.repo", "define_demo_execution_repo"
     )
@@ -193,7 +192,7 @@ def test_airflow_execution_date_tags_containerized(
         materialized_airflow_execution_date = None
         for result in results.values():
             for event in result:
-                if event.event_type_value == "STEP_MATERIALIZATION":
+                if event.event_type_value == "ASSET_MATERIALIZATION":
                     materialization = event.event_specific_data.materialization
                     materialization_entry = materialization.metadata_entries[0]
                     materialized_airflow_execution_date = materialization_entry.entry_data.text
